@@ -6,7 +6,7 @@
  * Copyright (c) 2004 Simon Newell <simonnew@speedymail.org>
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
- * Allows an attachment of mime type application/document (.doc, .pdf) to be
+ * Allows an attachment of mime type application/document (.doc, .pdf, .sxw) to be
  * opened and its contents displayed on browser.
  *
  * This php converts the attachment document into .html and displayed the html page.
@@ -82,13 +82,13 @@ $body = decodeBody($body, $encoding);
 
 // convert doc to html
 if (!(file_exists($dirname))) mkdir("$dirname", 0777);
-if (strcasecmp($doctype, "doc") == 0) {
+if (strcasecmp($doctype, "doc") == 0) { // for .doc conversion
   $fp = fopen("$dirname/$docname", "w");
   fwrite($fp, $body);
   fclose($fp);
   system($wvWarecmd);
   unlink("$dirname/$docname");
-} else if (strcasecmp($doctype, "pdf") == 0) {
+} else if (strcasecmp($doctype, "pdf") == 0) { // for .pdf conversion
   $fp = fopen("$dirname/$pdfname", "w");
   fwrite($fp, $body);
   fclose($fp);
@@ -117,7 +117,25 @@ echo '</b></td><tr><tr><td><CENTER><A HREF="'.$dwnld_url. '">'.
      "<TR><TD BGCOLOR=\"$color[4]\">";
 
 // display converted html page
-if (file_exists("$dirname/$htmlname")) { // conversion is successful
+if (strcasecmp($doctype, "sxw") == 0) { // for .sxw conversion
+	if (!(file_exists("$dirname/$prefixname"))) mkdir("$dirname/$prefixname", 0777);
+  $fp = fopen("$dirname/$prefixname/$sxwname", "w");
+  fwrite($fp, $body);
+  fclose($fp);
+  include_once("openoffice2html.php");
+	$prueba = new OpenOffice2html("$dirname/$prefixname/$sxwname", "$dirname", "$prefixname");
+  unlink("$dirname/$prefixname/$sxwname");
+}
+
+if (file_exists("$dirname/$prefixname/content.xml")) { // conversion is successful for .sxw format
+	echo '<br><a href="'.$msg_url.'">'. _("Back to message") . '</a><br>';
+  echo "<div align='center'><br><br><br><hr>";
+  echo _("Hosted by:") . "<a href=$sflink><img src=$sfimgsrc width='88' height='31' border='0' alt=" . _("SourceForge Logo") . "></a> ";
+  echo _("Powered by:") . "<a href=$sxwlink>" . _("OpenOffice2html") . "</a>";
+  echo " <a href=$pluginlink><img src=$pluginimgsrc width='205' height='35' border='0' alt=" . _("Plugin Logo") . "></a>";
+  echo "<hr></div>";
+  log_dir ($username, realpath($dirname)."/".$prefixname);
+} else if (file_exists("$dirname/$htmlname")) { // conversion is successful for .doc, .pdf format
   $handle = fopen("$dirname/$htmlname", "r");
   while (!feof($handle)) {
     $buffer = fgets($handle, 4096);
@@ -133,10 +151,10 @@ if (file_exists("$dirname/$htmlname")) { // conversion is successful
       	/* Strip HTML and PHP tags from image filename */
         $img = strip_tags($img);
       	if (isset($img) && $img != "") {
-      		log_image ($username, realpath($dirname)."/".$img);
+      		log_image ($username, realpath($dirname)."/".$img, 1);
           $pos = strpos($img, ".");
           $imgwmf = substr($img, 0, $pos) . ".wmf";
-      		log_image ($username, realpath($dirname)."/".$imgwmf);
+      		log_image ($username, realpath($dirname)."/".$imgwmf, 1);
 	      }
       }
     } else {
